@@ -1,20 +1,24 @@
 package Perinci::Use;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
+use experimental 'smartmatch';
 use Log::Any '$log';
 
 use Perinci::Access;
-use Perinci::Sub::Util qw(wrapres);
+use Perinci::Sub::Util qw(err);
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 our %SPEC;
 
 $SPEC{use_riap_package} = {
+    v => 1.1,
     summary => 'Use a Riap package as if it was a local Perl module',
-    result => 'undef',
+    result => {
+        schema => 'undef',
+    },
     description => <<'_',
 
 "Use" a remote code package over Riap protocol as if it was a local Perl module.
@@ -50,7 +54,7 @@ _
         },
         include => {
             summary     => 'Do not load all children, only load specified ones',
-            schema => ['array*' => {of=>'str*'}],
+            schema => ['array*' => of=>'str*'],
         },
     },
 };
@@ -67,8 +71,7 @@ sub use_riap_package {
 
     # try child_metas first
     my $res = $pa->request(child_metas => $url);
-    return wrapres(
-        [500, "Can't request action 'child_metas' on URL $url: "], $res)
+    return err(500, "Can't request action 'child_metas' on URL $url", $res)
         unless $res->[0] == 200 || $res->[0] == 502;
 
     my @e;
@@ -83,7 +86,7 @@ sub use_riap_package {
     } else {
         # try 'list' + later 'meta' for each child
         $res = $pa->request(list => $url, {detail=>1});
-        return wrapres([500, "Can't request action 'list' on URL $url: "], $res)
+        return err(500, "Can't request action 'list' on URL $url", $res)
             unless $res->[0] == 200;
         for my $r (@{$res->[2]}) {
             next unless $r->{type} eq 'function';
@@ -105,8 +108,7 @@ sub use_riap_package {
         # get metadata if not yet retrieved
         unless ($e->[2]) {
             $res = $pa->request(meta => $e->[1]);
-            return wrapres(
-                [500, "Can't request action 'meta' on URL $e->[1]: "], $res)
+            return err(500, "Can't request action 'meta' on URL $e->[1]", $res)
                 unless $res->[0] == 200;
             $e->[2] = $res->[2];
         }
@@ -149,17 +151,19 @@ sub import {
 1;
 # ABSTRACT: Use a Riap package like a local Perl module
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Perinci::Use - Use a Riap package like a local Perl module
 
 =head1 VERSION
 
-version 0.03
+This document describes version 0.04 of Perinci::Use (from Perl distribution Perinci-Use), released on 2014-05-26.
 
 =head1 SYNOPSIS
 
@@ -181,20 +185,80 @@ This module uses L<Log::Any> for logging.
 
 None are exported.
 
+
+=head2 use_riap_package(%args) -> [status, msg, result, meta]
+
+Use a Riap package as if it was a local Perl module.
+
+"Use" a remote code package over Riap protocol as if it was a local Perl module.
+Actually, what is being done is query the remote URL for available functions,
+and for each remote function, create a proxy function. The proxy function will
+then call the remote function.
+
+Currently only functions are imported. Variables and other entities are ignored.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<include> => I<array>
+
+Do not load all children, only load specified ones.
+
+=item * B<into>* => I<str>
+
+Perl package name to put proxy functions into.
+
+Example: 'Foo::Bar', 'Example::Module'.
+
+=item * B<url>* => I<str>
+
+Location of Riap package entity.
+
+Example: '/Foo/Bar/' (local Perl module), 'http://example.com/api/Module/'.
+
+=back
+
+Return value:
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
 =head1 SEE ALSO
 
 L<Perinci::Access>
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Use>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Use>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Use>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
